# FORCE NOARCH
# This package is noarch intentionally, although it supplies binaries,
# as they're not intended for the build platform, but for AVR.
# The related discussion can be found here:
# https://www.redhat.com/archives/fedora-devel-list/2009-February/msg02261.html
%global _binaries_in_noarch_packages_terminate_build 0

%define	target avr

%define tag_ver    %(tr '.' '_' <<< %{version})
%define doc_ver 2.2.0

Name:		%{target}-libc
Version:	2.2.1
Release:	%mkrel 1
Summary:	C library for use with GCC on Atmel AVR microcontrollers
Group:		Development/C
License:	BSD
URL:		https://avrdudes.github.io/avr-libc/
Source0:	https://github.com/avrdudes/avr-libc/releases/download/avr-libc-%{tag_ver}-release/avr-libc-%{version}.tar.bz2
Source1:	https://avrdudes.github.io/avr-libc/avr-libc-user-manual-%{doc_ver}.tar.bz2
Source2:	https://avrdudes.github.io/avr-libc/avr-libc-user-manual-%{doc_ver}.pdf
Patch0:		avr-libc-1.6.4-documentation.patch

BuildRequires:	cross-avr-gcc 
BuildArch:	noarch

%description
AVR Libc is a Free Software project whose goal is to provide a high quality C
library for use with GCC on Atmel AVR microcontrollers.

AVR Libc is licensed under a single unified license. This so-called modified
Berkeley license is intended to be compatible with most Free Software licenses
like the GPL, yet impose as little restrictions for the use of the library in
closed-source commercial applications as possible.

%files
%dir %{_prefix}/avr
%dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/AUTHORS
%doc %{_docdir}/%{name}-%{version}/LICENSE
%doc %{_docdir}/%{name}-%{version}/NEWS
%doc %{_docdir}/%{name}-%{version}/README.md
%doc %{_docdir}/%{name}-%{version}/TODO
%doc %{_docdir}/%{name}-%{version}/examples
%{_prefix}/avr/include
%{_prefix}/avr/lib
%{_bindir}/avr-man

#--------------------------------------------------------------------

%package docs
Summary:        AVR C library docs in html and pdf format
Group:          Development/C
Requires:       %{name} = %{version}-%{release}

%description docs
This package contains the AVR C library docs in html and pdf format; the main
package already contains the docs in man-page format (use "avr-man xxxx" to
access these).

%files docs
%doc html/
%doc pdf/

#--------------------------------------------------------------------

%prep
%setup -q -a1 
%patch -P 0 -p0

# Add html docs
bzip2 -dc %SOURCE1 | tar -xvvf -
mv avr-libc-user-manual-%{doc_ver} html
# Add pdf manual
mkdir pdf
cp %SOURCE2 pdf/avr-libc-user-manual-%{doc_ver}.pdf

%build
touch ChangeLog  # needed for autoreconf
autoreconf -vfi
# The ps doc weighs in at 7Mb versus 2.5 for the pdf and has little added value
./configure --prefix=%{_prefix} --host=avr --build=`./config.guess` # --enable-doc
%make_build libc libm
%make_build

%install
make install DESTDIR=$RPM_BUILD_ROOT

#mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/man
# put the man-pages in the FHS mandir and gzip them
#mkdir -p $RPM_BUILD_ROOT%{_prefix}/avr/share
#mv $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/man \
#  $RPM_BUILD_ROOT%{_prefix}/avr/share
#gzip $RPM_BUILD_ROOT%{_prefix}/avr/share/man/man3/*

# we only want to use %doc with an absolute path to avoid rpmbuild from erasing
# %{_docdir}/%{name}-%{version}
install -p -m 644 doc/TODO AUTHORS LICENSE NEWS \
  README.md $RPM_BUILD_ROOT%{_docdir}/%name-%{version}



%changelog
* Thu Jul 24 2025 danf <danf> 2.2.1-1.mga10
+ Revision: 2258770
- Update to ver. 2.2.1
- Update URLs

* Sat Apr 02 2022 umeabot <umeabot> 2.0.0-2.mga9
+ Revision: 1840115
- Mageia 9 Mass Rebuild

* Tue Jan 18 2022 mrambo3501 <mrambo3501> 2.0.0-1.mga9
+ Revision: 1768949
- version 2.0.0
- rediff Patch0
- delete upstreamed patches 1 and 2

* Mon Mar 23 2020 danf <danf> 1.7.1-15.mga8
+ Revision: 1559152
- Fix ARM build by using newer autoconf

* Tue Feb 11 2020 umeabot <umeabot> 1.7.1-14.mga8
+ Revision: 1490312
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 1.7.1-13.mga7
+ Revision: 1261836
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 1.7.1-12.mga7
+ Revision: 1259952
- Mageia 7 Mass Rebuild

* Fri Feb 19 2016 umeabot <umeabot> 1.7.1-11.mga6
+ Revision: 969728
- Mageia 6 Mass Rebuild

* Sun Sep 06 2015 ycantin <ycantin> 1.7.1-10.mga6
+ Revision: 873736
- Add missing include in delay.h (mga #12919)

* Wed Oct 15 2014 umeabot <umeabot> 1.7.1-8.mga5
+ Revision: 745501
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.7.1-7.mga5
+ Revision: 678077
- Mageia 5 Mass Rebuild

* Tue Dec 03 2013 danf <danf> 1.7.1-6.mga4
+ Revision: 554838
- Removed hack to stop stripping binaries since it's unneeded on Mageia
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 10 2012 dmorgan <dmorgan> 1.7.1-3.mga2
+ Revision: 194611
- Sync with fedora version

* Wed Sep 14 2011 dmorgan <dmorgan> 1.7.1-2.mga2
+ Revision: 143591
- Remove noarch as we install files in %%_libdir ( mga #2743)
+ kicer86 <kicer86>
- Group changed to Development/C

* Sun Jul 17 2011 kicer86 <kicer86> 1.7.1-1.mga2
+ Revision: 125251
- prefix set to %%{_libdir}
- lots of cleanups
- imported package avr-libc

